//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[HanHuOptions](../index.md)/[Companion](index.md)

# Companion

[common]\
object [Companion](index.md)

## Properties

| Name | Summary |
|---|---|
| [Default](-default.md) | [common]<br>val [Default](-default.md): [HanHuOptions](../index.md) |
